@@ -10,7 +10,7 @@
 # distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""Constants representing IANA media types."""
+"""This module contains constants representing IANA media types."""
 JSON = "application/json"
 CSV = "text/csv"
 OCTET_STREAM = "application/octet-stream"
