@@ -129,6 +129,9 @@ class SMDataParallelRunner(process.ProcessRunner):
             "orte_abort_on_non_zero_status",
             "1",
             "-mca",
+            "btl_vader_single_copy_mechanism",
+            "none",
+            "-mca",
             "plm_rsh_num_concurrent",
             str(num_hosts),
             "-x",
